Learn R Programming

coala (version 0.4.0)

feat_growth: Feature: Exponential population size growth/decline

Description

This feature changes the growth factor of a population at given point in time. This factor applies to the time interval further into the past from this point.

Usage

feat_growth(rate, population = "all", time = "0")

Arguments

rate
The growth rate. Can be a numeric or a parameter. See Details for an explanation how the rate affects the population size.
population
The population which growths/declines. Can be "all" for all populations, or the number of one population.
time
The time at which the growth rate is changed. Can also be a parameter.

Details

The population size changes by a factor $exp(-\alpha*t)$, where $\alpha$ is the growth parameter and $t$ is the time since the growth has started. For positive alpha, the population will decline backwards in time or grow forwards in time. For a negative value of $\alpha$ it will decline (forward in time).

See Also

For instantaneous population size changes: feat_size_change

Other features: feat_ignore_singletons, feat_migration, feat_mutation, feat_outgroup, feat_pop_merge, feat_recombination, feat_selection, feat_size_change, feat_unphased

Examples

Run this code
# Simulate a haploid population that has been expanding for
# the last 2*Ne generations
model <- coal_model(10, 1) +
  feat_growth(5, time = 0) +
  feat_growth(0, time = 1) +
  feat_mutation(10) +
  sumstat_sfs()
simulate(model)

Run the code above in your browser using DataLab