Learn R Programming

coala (version 0.4.0)

feat_outgroup: Feature: Outgroup

Description

This feature declares an existing population as outgroup. Outgroups are used to determine the ancestral allele in finite sites simulations and are required there. All individuals of the outgroup are ignored when calculating summary statistics. If the outgroup consists of multiple individuals, all positions where the individuals have different alleles are ignored.

Usage

feat_outgroup(population)

Arguments

population
The population that is marked as outgroup.

See Also

Other features: feat_growth, feat_ignore_singletons, feat_migration, feat_mutation, feat_pop_merge, feat_recombination, feat_selection, feat_size_change, feat_unphased

Examples

Run this code
# A simple finite sites model
model <- coal_model(c(4, 6, 1), 2, 10) +
   feat_outgroup(3) +
   feat_pop_merge(0.5, 2, 1) +
   feat_pop_merge(2, 3, 1) +
   feat_mutation(5, model = "GTR", gtr_rates = 1:6)

Run the code above in your browser using DataLab