Learn R Programming

coala (version 0.4.0)

feat_unphased: Feature: Unphased Sequences

Description

This simulates unphased data by randomly mixing the sites within one individual. Each position is randomly taken from a phased chromosome..

Usage

feat_unphased(samples_per_ind)

Arguments

samples_per_ind
The number of pseudo-chromosomes that are created from the phased chromosomes for each individual.

Value

The feature, which can be added to a model using `+`.

Details

For each individual, ploidy chromosomes are simulated, and samples_per_ind pseudo-chromosomes are created of these.

See Also

Other features: feat_growth, feat_ignore_singletons, feat_migration, feat_mutation, feat_outgroup, feat_pop_merge, feat_recombination, feat_selection, feat_size_change

Examples

Run this code
# Simulate unphased data in a diploid population
model <- coal_model(10, 1, ploidy = 2) +
  feat_mutation(10) +
  feat_unphased(2) +
  sumstat_seg_sites()
simulate(model)

# The same as before, but return only one chromosome for
# each individual:
model <- coal_model(10, 1, ploidy = 2) +
  feat_mutation(10) +
  feat_unphased(1) +
  sumstat_seg_sites()
simulate(model)

Run the code above in your browser using DataLab