This feature adds intra-locus recombination to a model. The rate is per locus
for unlinked loci and per trio for linked
locus trios. By default, the same recombination rate is used
for all loci, but it is possible to change this with par_variation
and par_zero_inflation. Coala assumes that recombination events
can occur between all neighboring bases.
Usage
feat_recombination(rate)
Arguments
rate
The recombination rate. Can be a numeric or a
parameter. The rate is equal to
$4*N0*r$, where $r$ is the probability that a
recombination event within the locus occurs in one generation.
Value
The feature, which can be added to a model using `+`.