Creates a feature that represents the sampling from one population
feat_sample(individuals, ploidy = 1, time = "0")The feature, which can be added to a model created with
coal_model using +.
The number of individuals that are sampled per population, given as a numeric vector.
The number of chromosomes that will be simulated per individual.
The time at which the sample is taken.
The loci for which this features is used. Can either be
"all" (default), in which case the feature is used for simulating
all loci, or a numeric vector. In the latter case, the feature is only
used for the loci added in locus_ commands with the corresponding
index starting from 1 in order in which the commands where added to the
model. For example, if a model has
locus_single(10) + locus_averaged(10, 11) + locus_single(12) and
this argument is c(2, 3), than the feature is used for all but
the first locus (that is locus 2 - 12).
For creating a model: coal_model
Other features:
feat_growth(),
feat_ignore_singletons(),
feat_migration(),
feat_mutation(),
feat_outgroup(),
feat_pop_merge(),
feat_recombination(),
feat_selection(),
feat_size_change(),
feat_unphased()