The name of the summary statistic. When simulating a model,
the value of the statistics are written to an entry of the returned list
with this name. Summary statistic names must be unique in a model.
transformation
An optional function for transforming the results
of the statistic. If specified, the results of the transformation are
returned instead of the original values.
Value
A list of segsites objects.
These can be treated as a matrix for
most applications. Rows are individuals, columns are SNPs.
See Also
For a description of the segregating sites class: create_segsites